Installation
============

.. tab-set::

    .. tab-item:: pip

        .. code-block:: sh

            pip install scitacean[sftp]

        If :class:`scitacean.transfer.sftp.SFTPFileTransfer` is not required, the ``sftp`` extra can be omitted.

    .. tab-item:: conda

        .. code-block:: sh

            conda install -c conda-forge scitacean
